import React, { useEffect } from 'react';
import ReactJSONView from 'react-json-view';
import { VisualizationPropTypes, VISComponentType } from '../../types';
import { GraphMetaData } from '@graphpolaris/shared/lib/data-access/statistics';
import { SettingsContainer } from '@graphpolaris/shared/lib/vis/configuration';
import Input from '@graphpolaris/shared/lib/components/inputs';

export interface RawJSONVisProps {
  showDataTypes: boolean;
  showObjectSize: boolean;
  enableClipboard: boolean;
  theme: string;
  iconStyle: string;
}

const configuration: RawJSONVisProps = {
  showDataTypes: false,
  showObjectSize: false,
  enableClipboard: false,
  theme: 'bright:inverted',
  iconStyle: 'circle',
};

export const RawJSONVis = React.memo(({ data, configuration }: VisualizationPropTypes) => {
  console.log(configuration);

  return (
    <div className="overflow-y-auto">
      <ReactJSONView
        src={data}
        collapsed={1}
        quotesOnKeys={false}
        style={{ padding: '20px' }}
        theme={configuration.theme}
        iconStyle={configuration.iconStyle}
        displayDataTypes={configuration.displayDataTypes}
        displayObjectSize={configuration.displayObjectSize}
        enableClipboard={configuration.enableClipboard}
      />
    </div>
  );
});

const RawJSONSettings = ({
  configuration,
  graph,
  updateSettings,
}: {
  configuration: RawJSONVisProps;
  graph: GraphMetaData;
  updateSettings: (val: any) => void;
}) => {
  return (
    <SettingsContainer>
      <Input
        type="dropdown"
        label="Select a theme"
        value={configuration.theme}
        options={['bright:inverted', 'monokai', 'ocean']}
        onChange={(val) => updateSettings({ theme: val })}
      />
      <Input
        type="dropdown"
        label="Icon style"
        value={configuration.iconStyle}
        options={['circle', 'square', 'triangle']}
        onChange={(val) => updateSettings({ iconStyle: val })}
      />
      {/* <Input
        type="boolean"
        label="Show data types"
        value={configuration.showDataTypes}
        onChange={(val) => updateSettings({ showDataTypes: val })}
      />
      <Input
        type="boolean"
        label="Show object size"
        value={configuration.showObjectSize}
        onChange={(val) => updateSettings({ showObjectSize: val })}
      />
      <Input
        type="boolean"
        label="Enable clipboard"
        value={configuration.enableClipboard}
        onChange={(val) => updateSettings({ enableClipboard: val })}
      /> */}
    </SettingsContainer>
  );
};

export const RawJSONComponent: VISComponentType = {
  displayName: 'RawJSONVis',
  component: RawJSONVis,
  settings: RawJSONSettings,
  configuration: configuration,
};
export default RawJSONComponent;
